@@ -30,7 +30,7 @@ qw==
 '''
 
 IDENTITY_NEW_STYLE_CERTS = {
-    'identity:0': {
+    'identity-service:0': {
         'keystone/0': {
             'ssl_cert_test-cn': 'keystone_provided_cert',
             'ssl_key_test-cn': 'keystone_provided_key',
@@ -39,7 +39,7 @@ IDENTITY_NEW_STYLE_CERTS = {
 }
 
 IDENTITY_OLD_STYLE_CERTS = {
-    'identity:0': {
+    'identity-service:0': {
         'keystone/0': {
             'ssl_cert': 'keystone_provided_cert',
             'ssl_key': 'keystone_provided_key',
@@ -57,7 +57,7 @@ class ApacheUtilsTests(TestCase):
             'relation_get',
             'relation_ids',
             'relation_list',
-            'subprocess',
+            'host',
         ]]
 
     def _patch(self, method):
@@ -121,7 +121,7 @@ class ApacheUtilsTests(TestCase):
             self.assertEqual(
                 apache_utils.retrieve_ca_cert('mycertfile'),
                 cert)
-            _open.assert_called_once_with('mycertfile', 'r')
+            _open.assert_called_once_with('mycertfile', 'rb')
 
     @patch.object(apache_utils.os.path, 'isfile')
     def test_retrieve_ca_cert_no_file(self, _isfile):
@@ -131,24 +131,3 @@ class ApacheUtilsTests(TestCase):
                 apache_utils.retrieve_ca_cert('mycertfile'),
                 None)
             self.assertFalse(_open.called)
-
-    @patch.object(apache_utils, 'retrieve_ca_cert')
-    def test_install_ca_cert_new_cert(self, _retrieve_ca_cert):
-        _retrieve_ca_cert.return_value = None
-        with patch_open() as (_open, _file):
-            apache_utils.install_ca_cert(cert)
-            _open.assert_called_once_with(
-                '/usr/local/share/ca-certificates/keystone_juju_ca_cert.crt',
-                'wb')
-            _file.write.assert_called_with(cert)
-        self.subprocess.check_call.assert_called_with(
-            ['update-ca-certificates', '--fresh'])
-
-    @patch.object(apache_utils, 'retrieve_ca_cert')
-    def test_install_ca_cert_old_cert(self, _retrieve_ca_cert):
-        _retrieve_ca_cert.return_value = cert
-        with patch_open() as (_open, _file):
-            apache_utils.install_ca_cert(cert)
-            self.assertFalse(_open.called)
-            self.assertFalse(_file.called)
-        self.assertFalse(self.subprocess.check_call.called)
