@@ -3,8 +3,10 @@ import json
 from subprocess import CalledProcessError
 import shutil
 import tempfile
+import types
 from mock import call, MagicMock, mock_open, patch, sentinel
 from testtools import TestCase
+from enum import Enum
 import yaml
 
 import six
@@ -60,6 +62,26 @@ class ConfigTest(TestCase):
         self.assertEqual(c['foo'], 'bar')
         self.assertEqual(c._prev_dict, None)
 
+    def test_init_empty_state_file(self):
+        d = dict(foo='bar')
+        c = hookenv.Config(d)
+
+        with open(c.path, 'w') as f:
+            f.close()
+
+        self.assertEqual(c['foo'], 'bar')
+        self.assertEqual(c._prev_dict, None)
+
+    def test_init_invalid_state_file(self):
+        d = dict(foo='bar')
+        c = hookenv.Config(d)
+
+        with open(c.path, 'w') as f:
+            f.write('blah')
+
+        self.assertEqual(c['foo'], 'bar')
+        self.assertEqual(c._prev_dict, None)
+
     def test_load_previous(self):
         d = dict(foo='bar')
         c = hookenv.Config()
@@ -318,15 +340,28 @@ class HelpersTest(TestCase):
             hookenv.log('foo', level)
             mock_call.assert_called_with(['juju-log', '-l', level, 'foo'])
 
+    @patch('subprocess.call')
+    def test_function_log_message(self, mock_call):
+        hookenv.function_log('foo')
+        mock_call.assert_called_with(['function-log', 'foo'])
+
+    @patch('subprocess.call')
+    def test_function_log_message_object(self, mock_call):
+        hookenv.function_log(object)
+        mock_call.assert_called_with(['function-log', repr(object)])
+
+    @patch('charmhelpers.core.hookenv._cache_config', None)
+    @patch('charmhelpers.core.hookenv.charm_dir')
     @patch('subprocess.check_output')
-    def test_gets_charm_config_with_scope(self, check_output):
-        config_data = 'bar'
-        check_output.return_value = json.dumps(config_data).encode('UTF-8')
+    def test_gets_charm_config_with_scope(self, check_output, charm_dir):
+        check_output.return_value = json.dumps(dict(baz='bar')).encode('UTF-8')
+        charm_dir.return_value = '/nonexistent'
 
         result = hookenv.config(scope='baz')
 
         self.assertEqual(result, 'bar')
-        check_output.assert_called_with(['config-get', 'baz', '--format=json'])
+        check_output.assert_called_with(['config-get', '--all',
+                                         '--format=json'])
 
         # The result can be used like a string
         self.assertEqual(result[1], 'a')
@@ -334,6 +369,8 @@ class HelpersTest(TestCase):
         # ... because the result is actually a string
         self.assert_(isinstance(result, six.string_types))
 
+    @patch('charmhelpers.core.hookenv.log', lambda *args, **kwargs: None)
+    @patch('charmhelpers.core.hookenv._cache_config', None)
     @patch('subprocess.check_output')
     def test_gets_missing_charm_config_with_scope(self, check_output):
         check_output.return_value = b''
@@ -341,21 +378,127 @@ class HelpersTest(TestCase):
         result = hookenv.config(scope='baz')
 
         self.assertEqual(result, None)
-        check_output.assert_called_with(['config-get', 'baz', '--format=json'])
+        check_output.assert_called_with(['config-get', '--all',
+                                         '--format=json'])
 
+    @patch('charmhelpers.core.hookenv._cache_config', None)
     @patch('charmhelpers.core.hookenv.charm_dir')
     @patch('subprocess.check_output')
     def test_gets_config_without_scope(self, check_output, charm_dir):
-        check_output.return_value = json.dumps(dict(foo='bar')).encode('UTF-8')
-        charm_dir.side_effect = tempfile.mkdtemp
+        check_output.return_value = json.dumps(dict(baz='bar')).encode('UTF-8')
+        charm_dir.return_value = '/nonexistent'
 
         result = hookenv.config()
 
         self.assertIsInstance(result, hookenv.Config)
-        self.assertEqual(result['foo'], 'bar')
+        self.assertEqual(result['baz'], 'bar')
         check_output.assert_called_with(['config-get', '--all',
                                          '--format=json'])
 
+    @patch('charmhelpers.core.hookenv.log')
+    @patch('charmhelpers.core.hookenv._cache_config', None)
+    @patch('charmhelpers.core.hookenv.charm_dir')
+    @patch('subprocess.check_output')
+    def test_gets_charm_config_invalid_json_with_scope(self,
+                                                       check_output,
+                                                       charm_dir,
+                                                       log):
+        check_output.return_value = '{"invalid: "json"}'.encode('UTF-8')
+        charm_dir.return_value = '/nonexistent'
+
+        result = hookenv.config(scope='invalid')
+
+        self.assertEqual(result, None)
+        cmd_line = ['config-get', '--all', '--format=json']
+        check_output.assert_called_with(cmd_line)
+        log.assert_called_with(
+            'Unable to parse output from config-get: '
+            'config_cmd_line="{}" message="{}"'
+            .format(str(cmd_line),
+                    "Expecting ':' delimiter: line 1 column 13 (char 12)"),
+            level=hookenv.ERROR,
+        )
+
+    @patch('charmhelpers.core.hookenv.log')
+    @patch('charmhelpers.core.hookenv._cache_config', None)
+    @patch('charmhelpers.core.hookenv.charm_dir')
+    @patch('subprocess.check_output')
+    def test_gets_charm_config_invalid_utf8_with_scope(self,
+                                                       check_output,
+                                                       charm_dir,
+                                                       log):
+        check_output.return_value = b'{"invalid: "json"}\x9D'
+        charm_dir.return_value = '/nonexistent'
+
+        result = hookenv.config(scope='invalid')
+
+        self.assertEqual(result, None)
+        cmd_line = ['config-get', '--all', '--format=json']
+        check_output.assert_called_with(cmd_line)
+        try:
+            # Python3
+            log.assert_called_with(
+                'Unable to parse output from config-get: '
+                'config_cmd_line="{}" message="{}"'
+                .format(str(cmd_line),
+                        "'utf8' codec can't decode byte 0x9d in position "
+                        "18: invalid start byte"),
+                level=hookenv.ERROR,
+            )
+        except AssertionError:
+            # Python2.7
+            log.assert_called_with(
+                'Unable to parse output from config-get: '
+                'config_cmd_line="{}" message="{}"'
+                .format(str(cmd_line),
+                        "'utf-8' codec can't decode byte 0x9d in position "
+                        "18: invalid start byte"),
+                level=hookenv.ERROR,
+            )
+
+    @patch('charmhelpers.core.hookenv._cache_config', {'baz': 'bar'})
+    @patch('charmhelpers.core.hookenv.charm_dir')
+    @patch('subprocess.check_output')
+    def test_gets_config_from_cache_without_scope(self,
+                                                  check_output,
+                                                  charm_dir):
+        charm_dir.return_value = '/nonexistent'
+
+        result = hookenv.config()
+
+        self.assertEqual(result['baz'], 'bar')
+        self.assertFalse(check_output.called)
+
+    @patch('charmhelpers.core.hookenv._cache_config', {'baz': 'bar'})
+    @patch('charmhelpers.core.hookenv.charm_dir')
+    @patch('subprocess.check_output')
+    def test_gets_config_from_cache_with_scope(self,
+                                               check_output,
+                                               charm_dir):
+        charm_dir.return_value = '/nonexistent'
+
+        result = hookenv.config('baz')
+
+        self.assertEqual(result, 'bar')
+
+        # The result can be used like a string
+        self.assertEqual(result[1], 'a')
+
+        # ... because the result is actually a string
+        self.assert_(isinstance(result, six.string_types))
+
+        self.assertFalse(check_output.called)
+
+    @patch('charmhelpers.core.hookenv._cache_config', {'foo': 'bar'})
+    @patch('subprocess.check_output')
+    def test_gets_missing_charm_config_from_cache_with_scope(self,
+                                                             check_output):
+
+        result = hookenv.config(scope='baz')
+
+        self.assertEqual(result, None)
+        self.assertFalse(check_output.called)
+
     @patch('charmhelpers.core.hookenv.os')
     def test_gets_the_local_unit(self, os_):
         os_.environ = {
@@ -512,6 +655,117 @@ class HelpersTest(TestCase):
                                          '-r', relid])
         self.assertFalse(relation_id.called)
 
+    @patch('charmhelpers.core.hookenv.local_unit')
+    @patch('charmhelpers.core.hookenv.goal_state')
+    @patch('charmhelpers.core.hookenv.has_juju_version')
+    def test_gets_expected_peer_units(self, has_juju_version, goal_state,
+                                      local_unit):
+        has_juju_version.return_value = True
+        goal_state.return_value = {
+            'units': {
+                'keystone/0': {
+                    'status': 'active',
+                    'since': '2018-09-27 11:38:28Z',
+                },
+                'keystone/1': {
+                    'status': 'active',
+                    'since': '2018-09-27 11:39:23Z',
+                },
+            },
+        }
+        local_unit.return_value = 'keystone/0'
+
+        result = hookenv.expected_peer_units()
+
+        self.assertIsInstance(result, types.GeneratorType)
+        self.assertEqual(sorted(result), ['keystone/1'])
+        has_juju_version.assertCalledOnceWith("2.4.0")
+        local_unit.assertCalledOnceWith()
+
+    @patch('charmhelpers.core.hookenv.has_juju_version')
+    def test_gets_expected_peer_units_wrong_version(self, has_juju_version):
+        has_juju_version.return_value = False
+
+        def x():
+            # local helper function to make testtools.TestCase.assertRaises
+            # work with generator
+            list(hookenv.expected_peer_units())
+
+        self.assertRaises(NotImplementedError, x)
+        has_juju_version.assertCalledOnceWith("2.4.0")
+
+    @patch('charmhelpers.core.hookenv.goal_state')
+    @patch('charmhelpers.core.hookenv.relation_type')
+    @patch('charmhelpers.core.hookenv.has_juju_version')
+    def test_gets_expected_related_units(self, has_juju_version, relation_type,
+                                         goal_state):
+        has_juju_version.return_value = True
+        relation_type.return_value = 'identity-service'
+        goal_state.return_value = {
+            'relations': {
+                'identity-service': {
+                    'glance': {
+                        'status': 'joined',
+                        'since': '2018-09-27 11:37:16Z'
+                    },
+                    'glance/0': {
+                        'status': 'active',
+                        'since': '2018-09-27 11:27:19Z'
+                    },
+                    'glance/1': {
+                        'status': 'active',
+                        'since': '2018-09-27 11:27:34Z'
+                    },
+                },
+            },
+        }
+
+        result = hookenv.expected_related_units()
+
+        self.assertIsInstance(result, types.GeneratorType)
+        self.assertEqual(sorted(result), ['glance/0', 'glance/1'])
+
+    @patch('charmhelpers.core.hookenv.goal_state')
+    @patch('charmhelpers.core.hookenv.has_juju_version')
+    def test_gets_expected_related_units_for_type(self, has_juju_version,
+                                                  goal_state):
+        has_juju_version.return_value = True
+        goal_state.return_value = {
+            'relations': {
+                'identity-service': {
+                    'glance': {
+                        'status': 'joined',
+                        'since': '2018-09-27 11:37:16Z'
+                    },
+                    'glance/0': {
+                        'status': 'active',
+                        'since': '2018-09-27 11:27:19Z'
+                    },
+                    'glance/1': {
+                        'status': 'active',
+                        'since': '2018-09-27 11:27:34Z'
+                    },
+                },
+            },
+        }
+
+        result = hookenv.expected_related_units('identity-service')
+
+        self.assertIsInstance(result, types.GeneratorType)
+        self.assertEqual(sorted(result), ['glance/0', 'glance/1'])
+
+    @patch('charmhelpers.core.hookenv.has_juju_version')
+    def test_gets_expected_related_units_wrong_version(self, has_juju_version):
+        has_juju_version.return_value = False
+
+        def x():
+            # local helper function to make testtools.TestCase.assertRaises
+            # work with generator
+            list(hookenv.expected_related_units())
+
+        self.assertRaises(NotImplementedError, x)
+        has_juju_version.assertCalledOnceWith("2.4.4")
+
     @patch('charmhelpers.core.hookenv.os')
     def test_gets_the_remote_unit(self, os_):
         os_.environ = {
@@ -1035,7 +1289,7 @@ class HelpersTest(TestCase):
         self.assertEqual("--file", command[1])
         temp_file = command[2]
         with open(temp_file, "r") as f:
-            self.assertEqual("{foo: bar}", f.read().strip())
+            self.assertEqual("foo: bar", f.read().strip())
         remove.assert_called_with(temp_file)
 
     @patch('charmhelpers.core.hookenv.local_unit', MagicMock())
@@ -1063,7 +1317,7 @@ class HelpersTest(TestCase):
         self.assertEqual("--file", command[1])
         temp_file = command[2]
         with open(temp_file, "r") as f:
-            self.assertEqual("{foo: '{''bar'': 1}'}", f.read().strip())
+            self.assertEqual("foo: '{''bar'': 1}'", f.read().strip())
         remove.assert_called_with(temp_file)
 
     def test_lists_relation_types(self):
@@ -1223,6 +1477,23 @@ class HelpersTest(TestCase):
         self.assertFalse(hookenv.resource_get('no-file'))
         self.assertFalse(hookenv.resource_get(None))
 
+    @patch('subprocess.check_output')
+    def test_goal_state_unsupported(self, check_output_):
+        check_output_.side_effect = OSError(2, 'goal-state')
+        self.assertRaises(NotImplementedError, hookenv.goal_state)
+
+    @patch('subprocess.check_output')
+    def test_goal_state(self, check_output_):
+        expect = {
+            'units': {},
+            'relations': {},
+        }
+        check_output_.return_value = json.dumps(expect).encode('UTF-8')
+        result = hookenv.goal_state()
+
+        self.assertEqual(result, expect)
+        check_output_.assert_called_with(['goal-state', '--format=json'])
+
     @patch('subprocess.check_output')
     def test_is_leader_unsupported(self, check_output_):
         check_output_.side_effect = OSError(2, 'is-leader')
@@ -1258,6 +1529,129 @@ class HelpersTest(TestCase):
         hookenv.application_version_set('v1.2.3')
         check_call_.assert_called_with(['application-version-set', 'v1.2.3'])
 
+    @patch.object(os, 'getenv')
+    @patch.object(hookenv, 'log')
+    def test_env_proxy_settings_juju_charm_all_selected(self, faux_log,
+                                                        get_env):
+        expected_settings = {
+            'HTTP_PROXY': 'http://squid.internal:3128',
+            'http_proxy': 'http://squid.internal:3128',
+            'HTTPS_PROXY': 'https://squid.internals:3128',
+            'https_proxy': 'https://squid.internals:3128',
+            'NO_PROXY': '192.0.2.0/24,198.51.100.0/24,.bar.com',
+            'no_proxy': '192.0.2.0/24,198.51.100.0/24,.bar.com',
+            'FTP_PROXY': 'ftp://ftp.internal:21',
+            'ftp_proxy': 'ftp://ftp.internal:21',
+        }
+
+        def get_env_side_effect(var):
+            return {
+                'HTTP_PROXY': None,
+                'HTTPS_PROXY': None,
+                'NO_PROXY': None,
+                'FTP_PROXY': None,
+                'JUJU_CHARM_HTTP_PROXY': 'http://squid.internal:3128',
+                'JUJU_CHARM_HTTPS_PROXY': 'https://squid.internals:3128',
+                'JUJU_CHARM_FTP_PROXY': 'ftp://ftp.internal:21',
+                'JUJU_CHARM_NO_PROXY': '192.0.2.0/24,198.51.100.0/24,.bar.com'
+            }[var]
+        get_env.side_effect = get_env_side_effect
+
+        proxy_settings = hookenv.env_proxy_settings()
+        get_env.assert_has_calls([call("HTTP_PROXY"),
+                                 call("HTTPS_PROXY"),
+                                 call("NO_PROXY"),
+                                 call("FTP_PROXY"),
+                                 call("JUJU_CHARM_HTTP_PROXY"),
+                                 call("JUJU_CHARM_HTTPS_PROXY"),
+                                 call("JUJU_CHARM_FTP_PROXY"),
+                                 call("JUJU_CHARM_NO_PROXY")],
+                                 any_order=True)
+        self.assertEqual(expected_settings, proxy_settings)
+        # Verify that we logged a warning about the cidr in NO_PROXY.
+        faux_log.assert_called_with(hookenv.RANGE_WARNING,
+                                    level=hookenv.WARNING)
+
+    @patch.object(os, 'getenv')
+    def test_env_proxy_settings_legacy_https(self, get_env):
+        expected_settings = {
+            'HTTPS_PROXY': 'http://squid.internal:3128',
+            'https_proxy': 'http://squid.internal:3128',
+        }
+
+        def get_env_side_effect(var):
+            return {
+                'HTTPS_PROXY': 'http://squid.internal:3128',
+                'JUJU_CHARM_HTTPS_PROXY': None,
+            }[var]
+        get_env.side_effect = get_env_side_effect
+
+        proxy_settings = hookenv.env_proxy_settings(['https'])
+        get_env.assert_has_calls([call("HTTPS_PROXY"),
+                                 call("JUJU_CHARM_HTTPS_PROXY")],
+                                 any_order=True)
+        self.assertEqual(expected_settings, proxy_settings)
+
+    @patch.object(os, 'getenv')
+    def test_env_proxy_settings_juju_charm_https(self, get_env):
+        expected_settings = {
+            'HTTPS_PROXY': 'http://squid.internal:3128',
+            'https_proxy': 'http://squid.internal:3128',
+        }
+
+        def get_env_side_effect(var):
+            return {
+                'HTTPS_PROXY': None,
+                'JUJU_CHARM_HTTPS_PROXY': 'http://squid.internal:3128',
+            }[var]
+        get_env.side_effect = get_env_side_effect
+
+        proxy_settings = hookenv.env_proxy_settings(['https'])
+        get_env.assert_has_calls([call("HTTPS_PROXY"),
+                                 call("JUJU_CHARM_HTTPS_PROXY")],
+                                 any_order=True)
+        self.assertEqual(expected_settings, proxy_settings)
+
+    @patch.object(os, 'getenv')
+    def test_env_proxy_settings_legacy_http(self, get_env):
+        expected_settings = {
+            'HTTP_PROXY': 'http://squid.internal:3128',
+            'http_proxy': 'http://squid.internal:3128',
+        }
+
+        def get_env_side_effect(var):
+            return {
+                'HTTP_PROXY': 'http://squid.internal:3128',
+                'JUJU_CHARM_HTTP_PROXY': None,
+            }[var]
+        get_env.side_effect = get_env_side_effect
+
+        proxy_settings = hookenv.env_proxy_settings(['http'])
+        get_env.assert_has_calls([call("HTTP_PROXY"),
+                                 call("JUJU_CHARM_HTTP_PROXY")],
+                                 any_order=True)
+        self.assertEqual(expected_settings, proxy_settings)
+
+    @patch.object(os, 'getenv')
+    def test_env_proxy_settings_juju_charm_http(self, get_env):
+        expected_settings = {
+            'HTTP_PROXY': 'http://squid.internal:3128',
+            'http_proxy': 'http://squid.internal:3128',
+        }
+
+        def get_env_side_effect(var):
+            return {
+                'HTTP_PROXY': None,
+                'JUJU_CHARM_HTTP_PROXY': 'http://squid.internal:3128',
+            }[var]
+        get_env.side_effect = get_env_side_effect
+
+        proxy_settings = hookenv.env_proxy_settings(['http'])
+        get_env.assert_has_calls([call("HTTP_PROXY"),
+                                 call("JUJU_CHARM_HTTP_PROXY")],
+                                 any_order=True)
+        self.assertEqual(expected_settings, proxy_settings)
+
 
 class HooksTest(TestCase):
     def setUp(self):
@@ -1424,15 +1818,88 @@ class HooksTest(TestCase):
         hookenv.action_fail(message)
         check_call.assert_called_with(['action-fail', message])
 
+    @patch('charmhelpers.core.hookenv.cmd_exists')
+    @patch('subprocess.check_output')
+    def test_function_get_with_key(self, check_output, cmd_exists):
+        function_data = 'bar'
+        check_output.return_value = json.dumps(function_data).encode('UTF-8')
+        cmd_exists.return_value = True
+
+        result = hookenv.function_get(key='foo')
+
+        self.assertEqual(result, 'bar')
+        check_output.assert_called_with(['function-get', 'foo', '--format=json'])
+
+    @patch('charmhelpers.core.hookenv.cmd_exists')
+    @patch('subprocess.check_output')
+    def test_function_get_without_key(self, check_output, cmd_exists):
+        check_output.return_value = json.dumps(dict(foo='bar')).encode('UTF-8')
+        cmd_exists.return_value = True
+
+        result = hookenv.function_get()
+
+        self.assertEqual(result['foo'], 'bar')
+        check_output.assert_called_with(['function-get', '--format=json'])
+
+    @patch('subprocess.check_call')
+    def test_function_set(self, check_call):
+        values = {'foo': 'bar', 'fooz': 'barz'}
+        hookenv.function_set(values)
+        # The order of the key/value pairs can change, so sort them before test
+        called_args = check_call.call_args_list[0][0][0]
+        called_args.pop(0)
+        called_args.sort()
+        self.assertEqual(called_args, ['foo=bar', 'fooz=barz'])
+
+    @patch('charmhelpers.core.hookenv.cmd_exists')
+    @patch('subprocess.check_call')
+    def test_function_fail(self, check_call, cmd_exists):
+        cmd_exists.return_value = True
+
+        message = "Ooops, the function failed"
+        hookenv.function_fail(message)
+        check_call.assert_called_with(['function-fail', message])
+
     def test_status_set_invalid_state(self):
         self.assertRaises(ValueError, hookenv.status_set, 'random', 'message')
 
+    def test_status_set_invalid_state_enum(self):
+
+        class RandomEnum(Enum):
+            FOO = 1
+        self.assertRaises(
+            ValueError,
+            hookenv.status_set,
+            RandomEnum.FOO,
+            'message')
+
     @patch('subprocess.call')
     def test_status(self, call):
         call.return_value = 0
         hookenv.status_set('active', 'Everything is Awesome!')
         call.assert_called_with(['status-set', 'active', 'Everything is Awesome!'])
 
+    @patch('subprocess.call')
+    def test_status_enum(self, call):
+        call.return_value = 0
+        hookenv.status_set(
+            hookenv.WORKLOAD_STATES.ACTIVE,
+            'Everything is Awesome!')
+        call.assert_called_with(['status-set', 'active', 'Everything is Awesome!'])
+
+    @patch('subprocess.call')
+    def test_status_app(self, call):
+        call.return_value = 0
+        hookenv.status_set(
+            'active',
+            'Everything is Awesome!',
+            application=True)
+        call.assert_called_with([
+            'status-set',
+            '--application',
+            'active',
+            'Everything is Awesome!'])
+
     @patch('subprocess.call')
     @patch.object(hookenv, 'log')
     def test_status_enoent(self, log, call):
@@ -1849,3 +2316,58 @@ ingress-addresses:
         # Return the private-address
         del d['ingress-address']
         self.assertEqual(hookenv.egress_subnets(), ['2001::D0:F00D/128'])
+
+    @patch('charmhelpers.core.hookenv.local_unit')
+    @patch('charmhelpers.core.hookenv.goal_state')
+    @patch('charmhelpers.core.hookenv.has_juju_version')
+    def test_unit_doomed(self, has_juju_version, goal_state, local_unit):
+        # We need to test for a minimum patch level, or we risk
+        # data loss by returning bogus results with Juju 2.4.0
+        has_juju_version.return_value = False
+        self.assertRaises(NotImplementedError, hookenv.unit_doomed)
+        has_juju_version.assertCalledOnceWith("2.4.1")
+        has_juju_version.return_value = True
+
+        goal_state.return_value = json.loads('''
+                                             {
+                                                "units": {
+                                                    "postgresql/0": {
+                                                        "status": "dying",
+                                                        "since": "2018-07-30 10:01:06Z"
+                                                    },
+                                                    "postgresql/1": {
+                                                        "status": "active",
+                                                        "since": "2018-07-30 10:22:39Z"
+                                                    }
+                                                },
+                                                "relations": {}
+                                             }
+                                             ''')
+        self.assertTrue(hookenv.unit_doomed('postgresql/0'))   # unit removed, status "dying"
+        self.assertFalse(hookenv.unit_doomed('postgresql/1'))  # unit exists, status "active", maybe other states
+        self.assertTrue(hookenv.unit_doomed('postgresql/2'))   # unit does not exist
+
+        local_unit.return_value = 'postgresql/0'
+        self.assertTrue(hookenv.unit_doomed())
+
+    def test_contains_addr_range(self):
+        # Contains cidr
+        self.assertTrue(hookenv._contains_range("192.168.1/20"))
+        self.assertTrue(hookenv._contains_range("192.168.0/24"))
+        self.assertTrue(
+            hookenv._contains_range("10.40.50.1,192.168.1/20,10.56.78.9"))
+        self.assertTrue(hookenv._contains_range("192.168.22/24"))
+        self.assertTrue(hookenv._contains_range("2001:db8::/32"))
+        self.assertTrue(hookenv._contains_range("*.foo.com"))
+        self.assertTrue(hookenv._contains_range(".foo.com"))
+        self.assertTrue(
+            hookenv._contains_range("192.168.1.20,.foo.com"))
+        self.assertTrue(
+            hookenv._contains_range("192.168.1.20,  .foo.com"))
+        self.assertTrue(
+            hookenv._contains_range("192.168.1.20,*.foo.com"))
+
+        # Doesn't contain cidr
+        self.assertFalse(hookenv._contains_range("192.168.1"))
+        self.assertFalse(hookenv._contains_range("192.168.145"))
+        self.assertFalse(hookenv._contains_range("192.16.14"))
